@@ -18,7 +18,6 @@ from gi.repository import GLib
 from pychess.compat import create_task
 from pychess.System.Log import log
 from pychess.System import conf, uistuff, prefix
-from pychess.System.debug import print_obj_referrers, print_muppy_sumary
 from pychess.Utils.const import HINT, NAME, SPY, NORMALCHESS
 from pychess.Utils.checkversion import checkversion
 from pychess.widgets import enginesDialog
@@ -68,6 +67,7 @@ class GladeHandlers(object):
 
         # debug leaking memory
         if Gdk.keyval_name(event.keyval) == "F12":
+            from pychess.System.debug import print_obj_referrers, print_muppy_sumary
             if event.get_state() & Gdk.ModifierType.SHIFT_MASK:
                 print_muppy_sumary()
             else:
@@ -431,7 +431,7 @@ class GladeHandlers(object):
 
 
 class PyChess(Gtk.Application):
-    def __init__(self, log_viewer, purge_recent, chess_file, ics_host, ics_port, loop):
+    def __init__(self, log_viewer, purge_recent, chess_file, ics_host, ics_port, loop, splash):
         Gtk.Application.__init__(self,
                                  application_id="org.pychess",
                                  flags=Gio.ApplicationFlags.NON_UNIQUE)
@@ -446,6 +446,7 @@ class PyChess(Gtk.Application):
         self.purge_recent = purge_recent
         self.chess_file = chess_file
         self.window = None
+        self.splash = splash
 
     def do_startup(self):
         Gtk.Application.do_startup(self)
@@ -528,6 +529,8 @@ class PyChess(Gtk.Application):
         conf.set("lightcolour", LIGHT)
         conf.set("darkcolour", DARK)
 
+        self.splash.destroy()
+
     def on_gmwidg_created(self, gamehandler, gmwidg):
         log.debug("GladeHandlers.on_gmwidg_created: starting")
         # Bring playing window to the front
