@@ -299,7 +299,7 @@ class EngineDiscoverer(GObject.GObject):
 
         def count(self_, name, engine, wentwell):
             if not wentwell:
-                print("cout not wentwell on engine", name)
+                print("count() not went well on engine", name)
                 self.engines.remove(engine)
 
             self.toBeRechecked[name][1] = True
@@ -454,6 +454,8 @@ class EngineDiscoverer(GObject.GObject):
                     result["protover"] = 2
                 if engine.protocol == "uci":
                     result["analyze"] = True
+                # if engine.elo > 0:
+                #     result["elo"] = engine.elo
 
                 # Attached interpreter
                 ext = os.path.splitext(name.lower())[1]
@@ -549,7 +551,7 @@ class EngineDiscoverer(GObject.GObject):
         def optionsCallback(engine):
             engine.setOptionStrength(diffi, forcePonderOff)
             engine.setOptionVariant(variant)
-            if secs > 0:
+            if secs > 0 or incr > 0:
                 engine.setOptionTime(secs, incr, moves)
 
         engine.connect("readyForOptions", optionsCallback)
