@@ -288,7 +288,7 @@ class Board:
         cord0, cord1 = move.cords
 
         if (self[move.cord1] is not None or flag == ENPASSANT) and \
-                not (self.variant == FISCHERRANDOMCHESS and flag in (QUEEN_CASTLE, KING_CASTLE)):
+                not (flag in (QUEEN_CASTLE, KING_CASTLE)):
             if self.variant == CRAZYHOUSECHESS:
                 piece = PAWN if flag == ENPASSANT or self[
                     move.cord1].promoted else self[move.cord1].piece
@@ -323,8 +323,9 @@ class Board:
                 newBoard[cord1].captured = False
                 newBoard[holding_coord] = None
         else:
-            if self.variant == ATOMICCHESS and (flag == ENPASSANT or
-                                                self[move.cord1] is not None):
+            if self.variant == ATOMICCHESS and (
+                flag == ENPASSANT or self[move.cord1] is not None) and (
+                    flag not in (QUEEN_CASTLE, KING_CASTLE)):
                 piece = self[move.cord0].piece
                 new_piece = Piece(self.color, piece, captured=True)
                 nth[1 - self.color] += 1
@@ -332,8 +333,7 @@ class Board:
                     1 - self.color])] = new_piece
                 newBoard[cord1] = None
             else:
-                if self.variant == FISCHERRANDOMCHESS and flag in (
-                        QUEEN_CASTLE, KING_CASTLE):
+                if flag in (QUEEN_CASTLE, KING_CASTLE):
                     king = newBoard[cord0]
                 else:
                     newBoard[cord1] = newBoard[cord0]
@@ -351,9 +351,8 @@ class Board:
             newBoard[Cord(finrook)] = newBoard[Cord(inirook)]
             if inirook != finrook:
                 newBoard[Cord(inirook)] = None
-            if self.variant == FISCHERRANDOMCHESS:
-                finking = self.board.fin_kings[self.color][side]
-                newBoard[Cord(finking)] = king
+            finking = self.board.fin_kings[self.color][side]
+            newBoard[Cord(finking)] = king
 
         if flag in PROMOTIONS:
             new_piece = Piece(self.color, PROMOTE_PIECE(flag))
