@@ -38,6 +38,7 @@ MAXPLY = 10
 # Maximum possible score. Mate in n ply is +/- (MATE_VALUE-n).
 # The hash structure only allows signed 16-bit scores.
 MATE_VALUE = MAXVAL = 32767
+MATE_DEPTH = 255
 
 
 def VALUE_AT_PLY(val, ply):
@@ -178,6 +179,15 @@ endingKing = (0, 6, 12, 18, 18, 12, 6, 0, 6, 12, 18, 24, 24, 18, 12, 6, 12, 18,
               32, 48, 48, 32, 24, 18, 12, 18, 24, 32, 32, 24, 18, 12, 6, 12,
               18, 24, 24, 18, 12, 6, 0, 6, 12, 18, 18, 12, 6, 0)
 
+racingKing = (0, 0, 0, 0, 0, 0, 0, 0,
+              500, 500, 500, 500, 500, 500, 500, 500,
+              950, 950, 950, 950, 950, 950, 950, 950,
+              1500, 1500, 1500, 1500, 1500, 1500, 1500, 1500,
+              2500, 2500, 2500, 2500, 2500, 2500, 2500, 2500,
+              4000, 4000, 4000, 4000, 4000, 4000, 4000, 4000,
+              6000, 6000, 6000, 6000, 6000, 6000, 6000, 6000,
+              14000, 14000, 14000, 14000, 14000, 14000, 14000, 14000)
+
 # Maps for bitboards
 
 d2e2 = (0x0018000000000000, 0x0000000000001800)
