@@ -11,7 +11,7 @@ from pychess.Utils.lutils.LBoard import LBoard
 from pychess.Utils.lutils.lmove import toPolyglot  # , FCORD, TCORD
 from pychess.Utils.GameModel import GameModel
 from pychess.Variants import name2variant, NormalBoard
-from pychess.perspectives import Perspective, perspective_manager
+from pychess.perspectives import Perspective, perspective_manager, panel_name
 from pychess.perspectives.database.gamelist import GameList
 from pychess.perspectives.database.OpeningTreePanel import OpeningTreePanel
 from pychess.perspectives.database.FilterPanel import FilterPanel
@@ -26,10 +26,10 @@ from pychess.Database.PgnImport import PgnImport, download_file
 from pychess.Database.JvR import JvR
 from pychess.Savers import fen, epd, olv
 from pychess.Savers.pgn import PGNFile
+from pychess.System import conf
 from pychess.System.protoopen import protoopen
 
 pgn_icon = load_icon(24, "application-x-chess-pgn", "pychess")
-BOOK_DEPTH = 8
 
 
 class Database(GObject.GObject, Perspective):
@@ -102,7 +102,7 @@ class Database(GObject.GObject, Perspective):
         self.notebooks = {"gamelist": new_notebook()}
         self.main_notebook = self.notebooks["gamelist"]
         for panel in self.sidePanels:
-            self.notebooks[panel.__name__] = new_notebook(panel.__name__)
+            self.notebooks[panel_name(panel.__name__)] = new_notebook(panel_name(panel.__name__))
 
         self.spinner = Gtk.Spinner()
         self.spinner.set_size_request(50, 50)
@@ -140,12 +140,14 @@ class Database(GObject.GObject, Perspective):
 
         self.docks["gamelist"] = (Gtk.Label(label="gamelist"), self.notebooks["gamelist"], None)
         for panel in self.sidePanels:
-            self.docks[panel.__name__][1] = self.notebooks[panel.__name__]
+            self.docks[panel_name(panel.__name__)][1] = self.notebooks[panel_name(panel.__name__)]
 
         self.load_from_xml()
 
         # Default layout of side panels
+        first_time_layout = False
         if not os.path.isfile(self.dockLocation):
+            first_time_layout = True
             leaf = self.dock.dock(self.docks["gamelist"][1], CENTER, self.docks["gamelist"][0], "gamelist")
             leaf.setDockable(False)
 
@@ -162,10 +164,9 @@ class Database(GObject.GObject, Perspective):
         self.dock.show_all()
         perspective_widget.show_all()
 
-        perspective_manager.set_perspective_menuitems("database", self.menuitems)
+        perspective_manager.set_perspective_menuitems("database", self.menuitems, default=first_time_layout)
 
-        perspective_manager.set_perspective_toolbuttons("database", [
-            self.import_button, self.save_as_button])
+        perspective_manager.set_perspective_toolbuttons("database", [self.import_button, self.save_as_button])
 
     def on_switch_page(self, notebook, page, page_num):
         if page in self.page_dict:
@@ -542,6 +543,8 @@ class Database(GObject.GObject, Perspective):
         self.progress_dialog.hide()
 
     def feed_book(self, records, positions):
+        BOOK_DEPTH_MAX = conf.get("book_depth_max")
+
         for rec in records:
             model = GameModel()
 
@@ -578,7 +581,7 @@ class Database(GObject.GObject, Perspective):
             boards = self.chessfile.parse_movetext(movetext, boards[0], -1)
 
             for board in boards:
-                if board.plyCount > BOOK_DEPTH:
+                if board.plyCount > BOOK_DEPTH_MAX:
                     break
                 move = board.lastMove
                 if move is not None:
