@@ -12,7 +12,7 @@ from gi.repository import Gtk
 from gi.repository import GObject
 
 from pychess.Savers.ChessFile import LoadingError
-from pychess.Savers import epd, fen, pgn, olv, png, database
+from pychess.Savers import epd, fen, pgn, olv, png, database, html, txt
 from pychess.System import conf
 from pychess.System.Log import log
 from pychess.System.protoopen import isWriteable
@@ -23,14 +23,13 @@ from pychess.Utils.const import UNFINISHED_STATES, ABORTED, ABORTED_AGREEMENT, L
 from pychess.Utils.Offer import Offer
 from pychess.widgets import gamewidget, mainwindow, new_notebook
 from pychess.widgets.gamenanny import game_nanny
-from pychess.perspectives import Perspective
-from pychess.perspectives import perspective_manager
+from pychess.perspectives import Perspective, perspective_manager, panel_name
 from pychess.widgets.pydock.PyDockTop import PyDockTop
 from pychess.widgets.pydock.__init__ import CENTER, EAST, SOUTH
 from pychess.ic.ICGameModel import ICGameModel
 
 enddir = {}
-savers = (pgn, epd, fen, olv, png)  # chessalpha2 is broken
+savers = (pgn, epd, fen, olv, png, html, txt)  # chessalpha2 is broken
 
 saveformats = Gtk.ListStore(str, str, GObject.TYPE_PYOBJECT)
 exportformats = Gtk.ListStore(str, str, GObject.TYPE_PYOBJECT)
@@ -328,7 +327,8 @@ class Games(GObject.GObject, Perspective):
                 print(repr(uri))
 
             try:
-                game.save(uri, saver, append, position)
+                flip = self.cur_gmwidg().board.view.rotation > 0
+                game.save(uri, saver, append, position, flip)
             except IOError as e:
                 d = Gtk.MessageDialog(mainwindow(), type=Gtk.MessageType.ERROR)
                 d.add_buttons(Gtk.STOCK_OK, Gtk.ResponseType.OK)
@@ -560,7 +560,7 @@ class Games(GObject.GObject, Perspective):
                           "messageArea": new_notebook("messageArea")}
         self.main_notebook = self.notebooks["board"]
         for panel in self.sidePanels:
-            self.notebooks[panel.__name__] = new_notebook(panel.__name__)
+            self.notebooks[panel_name(panel.__name__)] = new_notebook(panel_name(panel.__name__))
 
         # Initing headbook
 
@@ -589,12 +589,14 @@ class Games(GObject.GObject, Perspective):
 
         self.docks["board"] = (Gtk.Label(label="Board"), self.notebooks["board"], None)
         for panel in self.sidePanels:
-            self.docks[panel.__name__][1] = self.notebooks[panel.__name__]
+            self.docks[panel_name(panel.__name__)][1] = self.notebooks[panel_name(panel.__name__)]
 
         self.load_from_xml()
 
         # Default layout of side panels
+        first_time_layout = False
         if not os.path.isfile(self.dockLocation):
+            first_time_layout = True
             leaf = self.dock.dock(self.docks["board"][1],
                                   CENTER,
                                   Gtk.Label(label=self.docks["board"][0]),
@@ -660,7 +662,7 @@ class Games(GObject.GObject, Perspective):
         centerVBox.show_all()
         perspective_widget.show_all()
 
-        perspective_manager.set_perspective_menuitems("games", self.menuitems)
+        perspective_manager.set_perspective_menuitems("games", self.menuitems, default=first_time_layout)
 
         conf.notify_add("hideTabs", self.tabsCallback)
 
@@ -690,6 +692,14 @@ class Games(GObject.GObject, Perspective):
 
             headbook.connect("page-reordered", page_reordered, headbook)
 
+    def adjust_divider(self, diff):
+        """ Try to move paned (containing board) divider to show/hide captured pieces """
+        if self.dock is None:
+            return
+        child = self.dock.get_children()[0]
+        c1 = child.paned.get_child1()
+        c1.paned.set_position(c1.paned.get_position() + diff)
+
     def getheadbook(self):
         if len(self.key2gmwidg) == 0:
             return None
@@ -766,7 +776,7 @@ class Games(GObject.GObject, Perspective):
         self.notebooks["board"].append_page(gmwidg.boardvbox, None)
         gmwidg.boardvbox.show_all()
         for panel, instance in zip(self.sidePanels, gmwidg.panels):
-            self.notebooks[panel.__name__].append_page(instance, None)
+            self.notebooks[panel_name(panel.__name__)].append_page(instance, None)
             instance.show_all()
         self.notebooks["buttons"].append_page(gmwidg.stat_hbox, None)
         gmwidg.stat_hbox.show_all()
