@@ -10,7 +10,6 @@ from pychess.Utils.const import HINT, OPENING, SPY, BLACK, NULL_MOVE, ENDGAME, D
 from pychess.Utils.book import getOpenings
 from pychess.Utils.eco import get_eco
 from pychess.Utils.logic import legalMoveCount
-from pychess.Utils.EndgameTable import EndgameTable
 from pychess.Utils.Move import Move, toSAN, toFAN, listToMoves
 from pychess.Utils.lutils.lmovegen import newMove
 from pychess.Utils.lutils.lmove import ParsingError
@@ -340,6 +339,8 @@ class EngineAdvisor(Advisor):
 class EndgameAdvisor(Advisor):
     def __init__(self, store, tv, boardcontrol):
         Advisor.__init__(self, store, _("Endgame Table"), ENDGAME)
+        # deferred import to not slow down PyChess starting up
+        from pychess.Utils.EndgameTable import EndgameTable
         self.egtb = EndgameTable()
         # If mate in # was activated by double click let egtb do the rest
         self.auto_activate = False
@@ -480,7 +481,7 @@ class Sidepanel(object):
         adjustment = Gtk.Adjustment(value=1,
                                     lower=1,
                                     upper=9,
-                                    step_incr=1)
+                                    step_increment=1)
         self.multipvRenderer.set_property("adjustment", adjustment)
         self.multipvRenderer.set_property("editable", True)
         self.multipvRenderer.set_property("width_chars", 1)
@@ -728,7 +729,7 @@ width, height = 80, 23
 class StrengthCellRenderer(Gtk.CellRenderer):
     __gproperties__ = {
         "data":
-        (GObject.TYPE_PYOBJECT, "Data", "Data", GObject.PARAM_READWRITE),
+        (GObject.TYPE_PYOBJECT, "Data", "Data", GObject.ParamFlags.READABLE | GObject.ParamFlags.WRITABLE),
     }
 
     def __init__(self):
@@ -806,7 +807,7 @@ class CellRendererPixbufXt(Gtk.CellRendererPixbuf):
     __gproperties__ = {'active-state':
                        (GObject.TYPE_STRING, 'pixmap/active widget state',
                         'stock-icon name representing active widget state',
-                        None, GObject.PARAM_READWRITE)}
+                        None, GObject.ParamFlags.READABLE | GObject.ParamFlags.WRITABLE)}
     __gsignals__ = {'clicked': (GObject.SignalFlags.RUN_LAST, None,
                                 (GObject.TYPE_STRING, )), }
 
