@@ -270,7 +270,7 @@ class EnginesDialog():
                         if vmpath:
                             engine_command.append(vmpath)
                         if vm_args is not None:
-                            engine_command.append(vm_args)
+                            engine_command += vm_args
                         engine_command.append(new_engine)
 
                         # Search the engines based on the most expectable protocol
@@ -314,8 +314,6 @@ class EnginesDialog():
                         # active = self.widgets["engine_protocol_combo"].get_active()
                         protocol = "uci" if uci else "xboard"
 
-                        if vm_args is not None:
-                            vm_args = vm_args.split(",")
                         # print(binname, new_engine, protocol, vm_name, vm_args)
                         discoverer.addEngine(binname, new_engine, protocol, vm_name, vm_args)
                         self.cur_engine = binname
@@ -605,7 +603,7 @@ class KeyValueCellRenderer(Gtk.CellRenderer):
             ('Clear Hash', {'name': 'Clear Hash', 'type': 'button'})
     """
     __gproperties__ = {"data": (GObject.TYPE_PYOBJECT, "Data", "Data",
-                                GObject.PARAM_READWRITE)}
+                                GObject.ParamFlags.READABLE | GObject.ParamFlags.WRITABLE)}
 
     def __init__(self, model):
         GObject.GObject.__init__(self)
@@ -683,7 +681,7 @@ class KeyValueCellRenderer(Gtk.CellRenderer):
             adjustment = Gtk.Adjustment(value=int(value["value"]),
                                         lower=value["min"],
                                         upper=value["max"],
-                                        step_incr=1)
+                                        step_increment=1)
             self.spin_renderer.set_property("adjustment", adjustment)
             self.spin_renderer.set_property("text", str(value["value"]))
             self.set_property("mode", Gtk.CellRendererMode.EDITABLE)
