@@ -7,7 +7,6 @@
     events such as running out of time or piece movement events etc.
 """
 
-import asyncio
 import os
 from os import listdir
 from os.path import isdir, isfile, splitext
@@ -185,6 +184,8 @@ class HintTab:
         self.widgets["opening_check"].connect_after("toggled",
                                                     on_opening_check_toggled)
 
+        uistuff.keep(self.widgets["book_depth_max"], "book_depth_max")
+
         # Endgame
         egtb_path = conf.get("egtb_path")
         conf.set("egtb_path", egtb_path)
@@ -428,6 +429,7 @@ class SoundTab:
                     uri = opendialog.get_uri()
                     model = combobox.get_model()
                     conf.set("sounduri%d" % index, uri)
+                    self.sounduri[index] = uri
                     label = unquote(os.path.split(uri)[1])
                     if len(model) == 3:
                         model.append([audioIco, label])
